@@ -19,10 +19,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-export PATH=/tmp/hesa/TMP_INSTALL3/bin:${PATH}
-export LD_LIBRARY_PATH=/tmp/hesa/TMP_INSTALL3/lib
-export PYTHONPATH=/tmp/hesa/TMP_INSTALL3/lib
-export DYLD_LIBRARY_PATH=/tmp/hesa/TMP_INSTALL3/lib
+export LD_LIBRARY_PATH=/tmp/TMP_INSTALL3/lib
+export PYTHONPATH=/tmp/TMP_INSTALL3/lib
 
-/tmp/hesa/TMP_INSTALL3/bin/pardon.py $*
+/tmp/TMP_INSTALL3/bin/pardon.py
 
